@@ -6,7 +6,7 @@ Aliases to ease access to jsonrpclib classes
 :authors: Josh Marshall, Thomas Calmant
 :copyright: Copyright 2020, Thomas Calmant
 :license: Apache License 2.0
-:version: 0.4.1
+:version: 0.4.2
 
 ..
 
@@ -26,18 +26,24 @@ Aliases to ease access to jsonrpclib classes
 """
 
 # Easy access to utility methods and classes
-from jsonrpclib.jsonrpc import Server, ServerProxy
-from jsonrpclib.jsonrpc import MultiCall, Fault, ProtocolError, AppError
-from jsonrpclib.jsonrpc import loads, dumps, load, dump
-from jsonrpclib.jsonrpc import jloads, jdumps
-import jsonrpclib.history as history
-import jsonrpclib.utils as utils
+from jsonrpclib.jsonrpc import Server, ServerProxy  # noqa: F401
+from jsonrpclib.jsonrpc import (  # noqa: F401
+    MultiCall,
+    Fault,
+    ProtocolError,
+    AppError,
+    TransportError,
+)
+from jsonrpclib.jsonrpc import loads, dumps, load, dump  # noqa: F401
+from jsonrpclib.jsonrpc import jloads, jdumps  # noqa: F401
+import jsonrpclib.history as history  # noqa: F401
+import jsonrpclib.utils as utils  # noqa: F401
 
 # ------------------------------------------------------------------------------
 
 
 # Module version
-__version_info__ = (0, 4, 1)
+__version_info__ = (0, 4, 2)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
